@@ -3,9 +3,34 @@ use std::{
     env,
     fs::File,
     io::{self, Write},
+    time::SystemTime,
 };
 
-use crate::{flush_stdout, lib::get_templates};
+use crate::{
+    flush_stdout,
+    lib::{get_templates, CACHE_DIR, IS_ONLINE},
+};
+
+fn get_contents_remote(template_path: &str) -> anyhow::Result<Vec<u8>> {
+    let url = crate::parse_url!(template_path);
+    let contents = crate::remote::get_url(&url)?.text()?.as_bytes().to_vec();
+
+    println!("Getting template {}", template_path);
+
+    #[cfg(feature = "cache")]
+    {
+        let cache_file = CACHE_DIR
+            .to_owned()
+            .context("Failed to find cache dir")?
+            .join(format!("{}.gitignore", template_path));
+
+        let mut file = File::create(cache_file)?;
+
+        file.write_all(&contents)?;
+    }
+
+    Ok(contents)
+}
 
 pub fn pull_template() -> anyhow::Result<()> {
     let template = env::args()
@@ -45,24 +70,30 @@ pub fn pull_template() -> anyhow::Result<()> {
 
     #[cfg(feature = "cache")]
     let contents = {
-        use crate::cache::{CACHE_DIR, CACHE_ENABLED};
+        use crate::lib::CACHE_ENABLED;
 
         if CACHE_ENABLED.to_owned() {
             let cache_dir = CACHE_DIR.to_owned().context("Failed to parse cache dir")?;
             let file_path = cache_dir.join(format!("{}.gitignore", template_path));
+            let last_modified = file_path.metadata()?.modified()?;
 
-            std::fs::read(file_path)?
+            if SystemTime::now().duration_since(last_modified)?.as_secs() * 60 * 60 > 24
+                && IS_ONLINE.to_owned()
+            {
+                get_contents_remote(template_path)?
+            } else {
+                match std::fs::read(file_path) {
+                    Ok(v) => v,
+                    Err(_) => get_contents_remote(template_path)?,
+                }
+            }
         } else {
             Vec::new()
         }
     };
 
     #[cfg(not(feature = "cache"))]
-    let contents = {
-        let url = crate::parse_url!(template_path);
-
-        crate::remote::get_url(&url)?.text()?.as_bytes().to_vec()
-    };
+    let contents = get_contents_remote(template_path)?;
 
     let mut file = File::create(path).with_context(|| "Failed to create file")?;
     file.write_all(&contents)
